[−][src]Enum petgraph::visit::DfsEvent

pub enum DfsEvent<N> {
    Discover(N, Time),
    TreeEdge(N, N),
    BackEdge(N, N),
    CrossForwardEdge(N, N),
    Finish(N, Time),
}

A depth first search (DFS) visitor event.

Variants

Discover(N, Time)
TreeEdge(N, N)

An edge of the tree formed by the traversal.

BackEdge(N, N)

An edge to an already visited node.

CrossForwardEdge(N, N)

A cross or forward edge.

For an edge (u, v), if the discover time of v is greater than u, then it is a forward edge, else a cross edge.

Finish(N, Time)